/****************************************************************************
 **             - iotiny841.h -
 **
 **     This file declares the internal register addresses for ATtiny841.
 **
 **     Used with iccAVR and aAVR.
 **
 **     Copyright 2013 IAR Systems AB. All rights reserved.
 **
 **     File version: $Revision: $
 **
 ***************************************************************************/

#ifdef  __IAR_SYSTEMS_ICC__
#ifndef _SYSTEM_BUILD
#pragma system_include
#endif
#endif

#include "iomacro.h"

#if TID_GUARD(1)
#error This file should only be compiled with iccavr or aavr with processor option -v1
#endif /* TID_GUARD(1) */

#ifndef __IOTINY841_H


/* SFRs are local in assembler modules (so this file may need to be */
/* included in more than one module in the same source file), */
/* but #defines must only be made once per source file. */

/*==============================*/
/* Interrupt Vector Definitions */
/*==============================*/

/* NB! vectors are specified as byte addresses */

#define RESET_vect               (0x00) /* External Pin, Power-on Reset, Brown-out Reset and Watchdog Reset */
#define INT0_vect                (0x02) /* External Interrupt Request 0 */
#define PCINT0_vect              (0x04) /* Pin Change Interrupt Request 0 */
#define PCINT1_vect              (0x06) /* Pin Change Interrupt Request 1 */
#define WDT_vect                 (0x08) /* Watchdog Time-out Interrupt */
#define TIMER1_CAPT_vect         (0x0A) /* Timer/Counter1 Capture Event */
#define TIMER1_COMPA_vect        (0x0C) /* Timer/Counter1 Compare Match A */
#define TIMER1_COMPB_vect        (0x0E) /* Timer/Counter1 Compare Match B */
#define TIMER1_OVF_vect          (0x10) /* Timer/Counter1 Overflow */
#define TIMER0_COMPA_vect        (0x12) /* TimerCounter0 Compare Match A */
#define TIMER0_COMPB_vect        (0x14) /* TimerCounter0 Compare Match B */
#define TIMER0_OVF_vect          (0x16) /* Timer/Couner0 Overflow */
#define ANA_COMP0_vect           (0x18) /* Analog Comparator 0 */
#define ADC_vect                 (0x1A) /* ADC Conversion Complete */
#define EE_RDY_vect              (0x1C) /* EEPROM Ready */
#define ANA_COMP1_vect           (0x1E) /* Analog Comparator 1 */
#define TIMER2_CAPT_vect         (0x20) /* Timer/Counter2 Capture Event */
#define TIMER2_COMPA_vect        (0x22) /* Timer/Counter2 Compare Match A */
#define TIMER2_COMPB_vect        (0x24) /* Timer/Counter2 Compare Match B */
#define TIMER2_OVF_vect          (0x26) /* Timer/Counter2 Overflow */
#define SPI_vect                 (0x28) /* Serial Peripheral Interface */
#define USART0_START_vect        (0x2A) /* USART0, Start */
#define USART0_RX_vect           (0x2C) /* USART0, Rx Complete */
#define USART0_UDRE_vect         (0x2E) /* USART0 Data Register Empty */
#define USART0_TX_vect           (0x30) /* USART0, Tx Complete */
#define USART1_START_vect        (0x32) /* USART1, Start */
#define USART1_RX_vect           (0x34) /* USART1, Rx Complete */
#define USART1_UDRE_vect         (0x36) /* USART1 Data Register Empty */
#define USART1_TX_vect           (0x38) /* USART1, Tx Complete */
#define TWI_SLAVE_vect           (0x3A) /* Two-wire Serial Interface */


#ifdef __IAR_SYSTEMS_ASM__   
#ifndef ENABLE_BIT_DEFINITIONS
#define  ENABLE_BIT_DEFINITIONS
#endif /* ENABLE_BIT_DEFINITIONS */
#include "bitdefinitions/iotiny841.inc"
#endif /* __IAR_SYSTEMS_ASM__ */

#endif /* __IOTINY841_H (define part) */


/* Include the SFR part if this file has not been included before,
 * OR this file is included by the assembler (SFRs must be defined in
 * each assembler module). */
#if !defined(__IOTINY841_H) || defined(__IAR_SYSTEMS_ASM__)
#define __IOTINY841_H

#pragma language=save
#pragma language=extended

/*==========================*/
/* Predefined SFR Addresses */
/*==========================*/

/****************************************************************************
 * An example showing the SFR_B() macro call, 
 * the expanded result and usage of this result:
 *
 * SFR_B_R(0x1F,   AVR) Expands to:
 * __io union {
 *             unsigned char AVR;                 // The sfrb as 1 byte
 *             struct {                           // The sfrb as 8 bits
 *                     unsigned char AVR_Bit0:1,
 *                                   AVR_Bit1:1,
 *                                   AVR_Bit2:1,
 *                                   AVR_Bit3:1,
 *                                   AVR_Bit4:1,
 *                                   AVR_Bit5:1,
 *                                   AVR_Bit6:1,
 *                                   AVR_Bit7:1;
 *                    };
 *            } @ 0x1F;
 * Examples of how to use the expanded result:
 * AVR |= (1<<5);
 * or like this:
 * AVR_Bit5 = 1;
 *
 *
 *
 * An example showing the SFR_B_N() macro call, 
 * the expanded result and usage of this result:
 * SFR_B_N(0x25,  TCCR2, FOC2, WGM20, COM21, COM20, WGM21, CS22, CS21, CS20)
 *  Expands to:
 *  __io union { 
 *              unsigned char TCCR2; 
 *              struct { 
 *                      unsigned char TCCR2_Bit0:1, 
 *                                    TCCR2_Bit1:1, 
 *                                    TCCR2_Bit2:1, 
 *                                    TCCR2_Bit3:1, 
 *                                    TCCR2_Bit4:1, 
 *                                    TCCR2_Bit5:1, 
 *                                    TCCR2_Bit6:1, 
 *                                    TCCR2_Bit7:1; 
 *                     }; 
 *              struct { 
 *                      unsigned char TCCR2_CS20:1, 
 *                                    TCCR2_CS21:1, 
 *                                    TCCR2_CS22:1, 
 *                                    TCCR2_WGM21:1, 
 *                                    TCCR2_COM20:1, 
 *                                    TCCR2_COM21:1, 
 *                                    TCCR2_WGM20:1, 
 *                                    TCCR2_FOC2:1; 
 *                     }; 
 *             } @ 0x25;
 * Examples of how to use the expanded result:
 * TCCR2 |= (1<<5); 
 * or if ENABLE_BIT_DEFINITIONS is defined   
 * TCCR2 |= (1<<COM21);
 * or like this:
 * TCCR2_Bit5 = 1;
 * or like this:
 * TCCR2_COM21 = 1;
 ***************************************************************************/

 SFR_B_N(0xCA, TCCR2A, COM2A1, COM2A0, COM2B1, COM2B0, Dummy3, Dummy2, WGM21, WGM20)
 SFR_B_N(0xC9, TCCR2B, ICNC2, ICES2, Dummy5, WGM23, WGM22, CS22, CS21, CS20)
 SFR_B_N(0xC8, TCCR2C, FOC2A, FOC2B, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_W_N(0xC6, TCNT2, TCNT215, TCNT214, TCNT213, TCNT212, TCNT211, TCNT210, TCNT29, TCNT28, TCNT27, TCNT26, TCNT25, TCNT24, TCNT23, TCNT22, TCNT21, TCNT20)
 SFR_W_N(0xC4, OCR2A, OCR2A15, OCR2A14, OCR2A13, OCR2A12, OCR2A11, OCR2A10, OCR2A9, OCR2A8, OCR2A7, OCR2A6, OCR2A5, OCR2A4, OCR2A3, OCR2A2, OCR2A1, OCR2A0)
 SFR_W_N(0xC2, OCR2B, OCR2B15, OCR2B14, OCR2B13, OCR2B12, OCR2B11, OCR2B10, OCR2B9, OCR2B8, OCR2B7, OCR2B6, OCR2B5, OCR2B4, OCR2B3, OCR2B2, OCR2B1, OCR2B0)
 SFR_W_N(0xC0, ICR2, ICR215, ICR214, ICR213, ICR212, ICR211, ICR210, ICR29, ICR28, ICR27, ICR26, ICR25, ICR24, ICR23, ICR22, ICR21, ICR20)
 SFR_B_N(0xB2, SPCR, SPIE, SPE, DORD, MSTR, CPOL, CPHA, SPR1, SPR0)
 SFR_B_N(0xB1, SPSR, SPIF, WCOL, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, SPI2X)
 SFR_B_N(0xB0, SPDR, SPDR7, SPDR6, SPDR5, SPDR4, SPDR3, SPDR2, SPDR1, SPDR0)
 SFR_B_N(0xA5, TWSCRA, TWSHE, Dummy6, TWDIE, TWASIE, TWEN, TWSIE, TWPME, TWSME)
 SFR_B_N(0xA4, TWSCRB, Dummy7, Dummy6, Dummy5, Dummy4, TWHNM, TWAA, TWCMD1, TWCMD0)
 SFR_B_N(0xA3, TWSSRA, TWDIF, TWASIF, TWCH, TWRA, TWC, TWBE, TWDIR, TWAS)
 SFR_B_N(0xA2, TWSA, TWSA7, TWSA6, TWSA5, TWSA4, TWSA3, TWSA2, TWSA1, TWSA0)
 SFR_B_N(0xA1, TWSAM, TWSAM7, TWSAM6, TWSAM5, TWSAM4, TWSAM3, TWSAM2, TWSAM1, TWAE)
 SFR_B_N(0xA0, TWSD, TWSD7, TWSD6, TWSD5, TWSD4, TWSD3, TWSD2, TWSD1, TWSD0)
 SFR_B_N(0x96, UCSR1A, RXC1, TXC1, UDRE1, FE1, DOR1, UPE1, U2X1, MPCM1)
 SFR_B_N(0x95, UCSR1B, RXCIE1, TXCIE1, UDRIE1, RXEN1, TXEN1, UCSZ12, RXB81, TXB81)
 SFR_B_N(0x94, UCSR1C, UMSEL11, UMSEL10, UPM11, UPM10, USBS1, UCSZ11, UCSZ10, UCPOL1)
 SFR_B_N(0x93, UCSR1D, RXSIE1, RXS1, SFDE1, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_W_N(0x91, UBRR1, Dummy15, Dummy14, Dummy13, Dummy12, UBRR111, UBRR110, UBRR19, UBRR18, UBRR17, UBRR16, UBRR15, UBRR14, UBRR13, UBRR12, UBRR11, UBRR10)
 SFR_B_N(0x90, UDR1, UDR17, UDR16, UDR15, UDR14, UDR13, UDR12, UDR11, UDR10)
 SFR_B_N(0x86, UCSR0A, RXC0, TXC0, UDRE0, FE0, DOR0, UPE0, U2X0, MPCM0)
 SFR_B_N(0x85, UCSR0B, RXCIE0, TXCIE0, UDRIE0, RXEN0, TXEN0, UCSZ02, RXB80, TXB80)
 SFR_B_N(0x84, UCSR0C, UMSEL01, UMSEL00, UPM01, UPM00, USBS0, UCSZ01, UCSZ00, UCPOL0)
 SFR_B_N(0x83, UCSR0D, RXSIE0, RXS0, SFDE0, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_W_N(0x81, UBRR0, Dummy15, Dummy14, Dummy13, Dummy12, UBRR011, UBRR010, UBRR09, UBRR08, UBRR07, UBRR06, UBRR05, UBRR04, UBRR03, UBRR02, UBRR01, UBRR00)
 SFR_B_N(0x80, UDR0, UDR07, UDR06, UDR05, UDR04, UDR03, UDR02, UDR01, UDR00)
 SFR_B_N(0x77, OSCCAL1, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, OSCCAL11, OSCCAL10)
 SFR_B_N(0x76, OSCTCAL0B, OSCTCAL0B7, OSCTCAL0B6, OSCTCAL0B5, OSCTCAL0B4, OSCTCAL0B3, OSCTCAL0B2, OSCTCAL0B1, OSCTCAL0B0)
 SFR_B_N(0x75, OSCTCAL0A, OSCTCAL0A7, OSCTCAL0A6, OSCTCAL0A5, OSCTCAL0A4, OSCTCAL0A3, OSCTCAL0A2, OSCTCAL0A1, OSCTCAL0A0)
 SFR_B_N(0x74, OSCCAL0, OSCCAL07, OSCCAL06, OSCCAL05, OSCCAL04, OSCCAL03, OSCCAL02, OSCCAL01, OSCCAL00)
 SFR_B_N(0x73, CLKPR, Dummy7, Dummy6, Dummy5, Dummy4, CLKPS3, CLKPS2, CLKPS1, CLKPS0)
 SFR_B_N(0x72, CLKCR, OSCRDY, CSTR, CKOUTC, SUT, CKSEL3, CKSEL2, CKSEL1, CKSEL0)
 SFR_B_N(0x71, CCP, CCP7, CCP6, CCP5, CCP4, CCP3, CCP2, CCP1, CCP0)
 SFR_B_N(0x70, PRR, PRTWI, PRUSART1, PRUSART0, PRSPI, PRTIM2, PRTIM1, PRTIM0, PRADC)
 SFR_B_N(0x6A, PHDE, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, PHDEA1, PHDEA0)
 SFR_B_N(0x68, TOCPMSA1, TOCC7S1, TOCC7S0, TOCC6S1, TOCC6S0, TOCC5S1, TOCC5S0, TOCC4S1, TOCC4S0)
 SFR_B_N(0x67, TOCPMSA0, TOCC3S1, TOCC3S0, TOCC2S1, TOCC2S0, TOCC1S1, TOCC1S0, TOCC0S1, TOCC0S0)
 SFR_B_N(0x66, TOCPMCOE, TOCC7OE, TOCC6OE, TOCC5OE, TOCC4OE, TOCC3OE, TOCC2OE, TOCC1OE, TOCC0OE)
 SFR_B_N(0x65, REMAP, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, U0MAP, SPIMAP)
 SFR_B_N(0x64, PORTCR, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, BBMB, BBMA)
 SFR_B_N(0x63, PUEA, PUEA7, PUEA6, PUEA5, PUEA4, PUEA3, PUEA2, PUEA1, PUEA0)
 SFR_B_N(0x62, PUEB, Dummy7, Dummy6, Dummy5, Dummy4, PUEB3, PUEB2, PUEB1, PUEB0)
 SFR_B_N(0x61, DIDR1, Dummy7, Dummy6, Dummy5, Dummy4, ADC9D, ADC8D, ADC10D, ADC11D)
 SFR_B_N(0x60, DIDR0, ADC7D, ADC6D, ADC5D, ADC4D, ADC3D, ADC2D, ADC1D, ADC0D)
 SFR_B_N(0x3F, SREG, I, T, H, S, V, N, Z, C)
 SFR_W_N(0x3D, SP, Dummy15, Dummy14, Dummy13, Dummy12, Dummy11, SP10, SP9, SP8, SP7, SP6, SP5, SP4, SP3, SP2, SP1, SP0)
 SFR_B_N(0x3C, OCR0B, OCR0B7, OCR0B6, OCR0B5, OCR0B4, OCR0B3, OCR0B2, OCR0B1, OCR0B0)
 SFR_B_N(0x3B, GIMSK, Dummy7, INT0, PCIE1, PCIE0, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_B_N(0x3A, GIFR, Dummy7, INTF0, PCIF1, PCIF0, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_B_N(0x39, TIMSK0, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, OCIE0B, OCIE0A, TOIE0)
 SFR_B_N(0x38, TIFR0, Dummy7, Dummy6, Dummy5, Dummy4, Dummy3, OCF0B, OCF0A, TOV0)
 SFR_B_N(0x37, SPMCSR, Dummy7, Dummy6, RSIG, CTPB, RFLB, PGWRT, PGERS, SPMEN)
 SFR_B_N(0x36, OCR0A, OCR0A7, OCR0A6, OCR0A5, OCR0A4, OCR0A3, OCR0A2, OCR0A1, OCR0A0)
 SFR_B_N(0x35, MCUCR, Dummy7, Dummy6, SE, SM1, SM0, Dummy2, ISC01, ISC00)
 SFR_B_N(0x34, MCUSR, Dummy7, Dummy6, Dummy5, Dummy4, WDRF, BORF, EXTRF, PORF)
 SFR_B_N(0x33, TCCR0B, FOC0A, FOC0B, Dummy5, Dummy4, WGM02, CS02, CS01, CS00)
 SFR_B_N(0x32, TCNT0, TCNT07, TCNT06, TCNT05, TCNT04, TCNT03, TCNT02, TCNT01, TCNT00)
 SFR_B_N(0x30, TCCR0A, COM0A1, COM0A0, COM0B1, COM0B0, Dummy3, Dummy2, WGM01, WGM00)
 SFR_B_N(0x2F, TCCR1A, COM1A1, COM1A0, COM1B1, COM1B0, Dummy3, Dummy2, WGM11, WGM10)
 SFR_B_N(0x2E, TCCR1B, ICNC1, ICES1, Dummy5, WGM13, WGM12, CS12, CS11, CS10)
 SFR_W_N(0x2C, TCNT1, TCNT115, TCNT114, TCNT113, TCNT112, TCNT111, TCNT110, TCNT19, TCNT18, TCNT17, TCNT16, TCNT15, TCNT14, TCNT13, TCNT12, TCNT11, TCNT10)
 SFR_W_N(0x2A, OCR1A, OCR1A15, OCR1A14, OCR1A13, OCR1A12, OCR1A11, OCR1A10, OCR1A9, OCR1A8, OCR1A7, OCR1A6, OCR1A5, OCR1A4, OCR1A3, OCR1A2, OCR1A1, OCR1A0)
 SFR_W_N(0x28, OCR1B, OCR1B15, OCR1B14, OCR1B13, OCR1B12, OCR1B11, OCR1B10, OCR1B9, OCR1B8, OCR1B7, OCR1B6, OCR1B5, OCR1B4, OCR1B3, OCR1B2, OCR1B1, OCR1B0)
 SFR_W_N(0x24, ICR1, ICR115, ICR114, ICR113, ICR112, ICR111, ICR110, ICR19, ICR18, ICR17, ICR16, ICR15, ICR14, ICR13, ICR12, ICR11, ICR10)
 SFR_B_N(0x23, GTCCR, TSM, Dummy6, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, PSR)
 SFR_B_N(0x22, TCCR1C, FOC1A, FOC1B, Dummy5, Dummy4, Dummy3, Dummy2, Dummy1, Dummy0)
 SFR_B_N(0x21, WDTCSR, WDIF, WDIE, Dummy5, Dummy4, WDE, WDP2, WDP1, WDP0)
 SFR_B_N(0x20, PCMSK1, Dummy7, Dummy6, Dummy5, Dummy4, PCMSK13, PCMSK12, PCMSK11, PCMSK10)
 SFR_W_N(0x1E, EEAR, Dummy15, Dummy14, Dummy13, Dummy12, Dummy11, Dummy10, Dummy9, EEAR8, EEAR7, EEAR6, EEAR5, EEAR4, EEAR3, EEAR2, EEAR1, EEAR0)
 SFR_B_N(0x1D, EEDR, EEDR7, EEDR6, EEDR5, EEDR4, EEDR3, EEDR2, EEDR1, EEDR0)
 SFR_B_N(0x1C, EECR, Dummy7, Dummy6, EEPM1, EEPM0, EERIE, EEMPE, EEPE, EERE)
 SFR_B_N(0x1B, PORTA, PORTA7, PORTA6, PORTA5, PORTA4, PORTA3, PORTA2, PORTA1, PORTA0)
 SFR_B_N(0x1A, DDRA, DDRA7, DDRA6, DDRA5, DDRA4, DDRA3, DDRA2, DDRA1, DDRA0)
 SFR_B_N(0x19, PINA, PINA7, PINA6, PINA5, PINA4, PINA3, PINA2, PINA1, PINA0)
 SFR_B_N(0x18, PORTB, Dummy7, Dummy6, Dummy5, Dummy4, PORTB3, PORTB2, PORTB1, PORTB0)
 SFR_B_N(0x17, DDRB, Dummy7, Dummy6, Dummy5, Dummy4, DDRB3, DDRB2, DDRB1, DDRB0)
 SFR_B_N(0x16, PINB, Dummy7, Dummy6, Dummy5, Dummy4, PINB3, PINB2, PINB1, PINB0)
 SFR_B_N(0x15, GPIOR2, GPIOR27, GPIOR26, GPIOR25, GPIOR24, GPIOR23, GPIOR22, GPIOR21, GPIOR20)
 SFR_B_N(0x14, GPIOR1, GPIOR17, GPIOR16, GPIOR15, GPIOR14, GPIOR13, GPIOR12, GPIOR11, GPIOR10)
 SFR_B_N(0x13, GPIOR0, GPIOR07, GPIOR06, GPIOR05, GPIOR04, GPIOR03, GPIOR02, GPIOR01, GPIOR00)
 SFR_B_N(0x12, PCMSK0, PCMSK07, PCMSK06, PCMSK05, PCMSK04, PCMSK03, PCMSK02, PCMSK01, PCMSK00)
 SFR_B_N(0x11, TIMSK2, Dummy7, Dummy6, ICIE2, Dummy4, Dummy3, OCIE2B, OCIE2A, TOIE2)
 SFR_B_N(0x10, TIFR2, Dummy7, Dummy6, ICF2, Dummy4, Dummy3, OCF2B, OCF2A, TOV2)
 SFR_B_N(0x0F, TIMSK1, Dummy7, Dummy6, ICIE1, Dummy4, Dummy3, OCIE1B, OCIE1A, TOIE1)
 SFR_B_N(0x0E, TIFR1, Dummy7, Dummy6, ICF1, Dummy4, Dummy3, OCF1B, OCF1A, TOV1)
 SFR_B_N(0x0D, ACSR1B, HSEL1, HLEV1, Dummy5, ACOE1, Dummy3, ACME1, Dummy1, Dummy0)
 SFR_B_N(0x0C, ACSR1A, ACD1, ACBG1, ACO1, ACI1, ACIE1, ACIC1, ACIS1, ACIS0)
 SFR_B_N(0x0B, ACSR0B, HSEL0, HLEV0, Dummy5, ACOE0, ACNMUX1, ACNMUX0, ACPMUX1, ACPMUX0)
 SFR_B_N(0x0A, ACSR0A, ACD0, ACPMUX2, ACO0, ACI0, ACIE0, ACIC0, ACIS1, ACIS0)
 SFR_B_N(0x09, ADMUXA, Dummy7, Dummy6, MUX5, MUX4, MUX3, MUX2, MUX1, MUX0)
 SFR_B_N(0x08, ADMUXB, REFS2, REFS1, REFS0, Dummy4, Dummy3, Dummy2, GSEL1, GSEL0)
 SFR_W_N(0x06, ADC, ADC15, ADC14, ADC13, ADC12, ADC11, ADC10, ADC9, ADC8, ADC7, ADC6, ADC5, ADC4, ADC3, ADC2, ADC1, ADC0)
 SFR_B_N(0x05, ADCSRA, ADEN, ADSC, ADATE, ADIF, ADIE, ADPS2, ADPS1, ADPS0)
 SFR_B_N(0x04, ADCSRB, Dummy7, Dummy6, Dummy5, Dummy4, ADLAR, ADTS2, ADTS1, ADTS0)

#pragma language=restore

#ifndef __IAR_SYSTEMS_ASM__
#include "bitdefinitions/iotiny841.inc"
#endif

#endif /* __IOTINY841_H (SFR part) */

